Rustlink
This library provides a simple interface to fetch price data from the Chainlink decentralized data feed.
Core is the main module that contains the main struct Rustlink that you will need to interact with.
Structs
- Configuration
- Configuration
- Contracts
- Rustlink
- Rustlink instance. This is the main struct that you will interact with.
- RustlinkJS
- RustlinkJS is a JavaScript wrapper for Rustlink. It allows you to create a Rustlink instance in JavaScript and start fetching data when you use WASM. You should use this one when you want to use Rustlink in a web environment.
Enums
- Reflector
- Rustlink allows you as a developer to retrieve the sought Chainlink data in different ways.